@@ -39,15 +39,6 @@ LOG = log.getLogger(__name__)
 
 NULL_DOMAIN_ID = '<<keystone.domain.root>>'
 
-# FIXME(stephenfin): Remove this as soon as we're done reworking the
-# migrations. Until then, this is necessary to allow us to use the native
-# alembic tooling (which won't register opts). Alternatively, maybe
-# the server default *shouldn't* rely on a (changeable) config option value?
-try:
-    service_provider_relay_state_prefix_default = CONF.saml.relay_state_prefix
-except Exception:
-    service_provider_relay_state_prefix_default = 'ss:mem:'
-
 
 def upgrade():
     bind = op.get_bind()
@@ -510,7 +501,7 @@ def upgrade():
             'relay_state_prefix',
             sql.String(256),
             nullable=False,
-            server_default=service_provider_relay_state_prefix_default,
+            server_default=CONF.saml.relay_state_prefix,
         ),
         mysql_engine='InnoDB',
         mysql_charset='utf8',
