@@ -54,6 +54,31 @@ class ShadowUsers(base.ShadowUsersDriverBase):
             session.add(user_ref)
             return identity_base.filter_user(user_ref.to_dict())
 
+    @sql.handle_conflicts(conflict_type='federated_user')
+    def create_federated_object(self, fed_dict):
+        with sql.session_for_write() as session:
+            fed_ref = model.FederatedUser.from_dict(fed_dict)
+            session.add(fed_ref)
+
+    def delete_federated_object(self, user_id):
+        with sql.session_for_write() as session:
+            q = session.query(model.FederatedUser)
+            q = q.filter(model.FederatedUser.user_id == user_id)
+            q.delete(False)
+
+    def get_federated_objects(self, user_id):
+        with sql.session_for_read() as session:
+            query = session.query(model.FederatedUser)
+            query = query.filter(model.FederatedUser.user_id == user_id)
+            fed_ref = []
+            for row in query:
+                m = model.FederatedUser(
+                    idp_id=row.idp_id,
+                    protocol_id=row.protocol_id,
+                    unique_id=row.unique_id)
+                fed_ref.append(m.to_dict())
+            return base.federated_objects_to_list(fed_ref)
+
     def _update_query_with_federated_statements(self, hints, query):
         statements = []
         for filter_ in hints.filters:
@@ -73,7 +98,8 @@ class ShadowUsers(base.ShadowUsersDriverBase):
             x for x in hints.filters if x['name'] not in ('idp_id',
                                                           'protocol_id',
                                                           'unique_id')]
-        query = query.filter(sqlalchemy.and_(*statements))
+        if statements:
+            query = query.filter(sqlalchemy.and_(*statements))
         return query
 
     def get_federated_users(self, hints):
@@ -131,7 +157,7 @@ class ShadowUsers(base.ShadowUsersDriverBase):
     def set_last_active_at(self, user_id):
         if CONF.security_compliance.disable_user_account_days_inactive:
             with sql.session_for_write() as session:
-                user_ref = session.query(model.User).get(user_id)
+                user_ref = session.get(model.User, user_id)
                 user_ref.last_active_at = datetime.datetime.utcnow().date()
 
     @sql.handle_conflicts(conflict_type='federated_user')
@@ -184,7 +210,7 @@ class ShadowUsers(base.ShadowUsersDriverBase):
             return identity_base.filter_user(user_ref.to_dict())
 
     def _get_user(self, session, user_id):
-        user_ref = session.query(model.User).get(user_id)
+        user_ref = session.get(model.User, user_id)
         if not user_ref:
             raise exception.UserNotFound(user_id=user_id)
         return user_ref
@@ -195,3 +221,32 @@ class ShadowUsers(base.ShadowUsersDriverBase):
             fed_user_refs = sql.filter_limit_query(model.FederatedUser, query,
                                                    hints)
             return [x.to_dict() for x in fed_user_refs]
+
+    def add_user_to_group_expires(self, user_id, group_id):
+        def get_federated_user():
+            with sql.session_for_read() as session:
+                query = session.query(model.FederatedUser)
+                query = query.filter_by(user_id=user_id)
+                user = query.first()
+                if not user:
+                    # Note(knikolla): This shouldn't really ever happen, since
+                    # this requires the user to already be logged in.
+                    raise exception.UserNotFound(user_id=user_id)
+                return user
+
+        with sql.session_for_write() as session:
+            user = get_federated_user()
+            query = session.query(model.ExpiringUserGroupMembership)
+            query = query.filter_by(user_id=user_id)
+            query = query.filter_by(group_id=group_id)
+            membership = query.first()
+
+            if membership:
+                membership.last_verified = datetime.datetime.utcnow()
+            else:
+                session.add(model.ExpiringUserGroupMembership(
+                    user_id=user_id,
+                    group_id=group_id,
+                    idp_id=user.idp_id,
+                    last_verified=datetime.datetime.utcnow()
+                ))
