@@ -55,8 +55,8 @@ PROVIDERS = provider_api.ProviderAPIs
 class SqlTests(unit.SQLDriverOverrides, unit.TestCase):
 
     def setUp(self):
-        super(SqlTests, self).setUp()
-        self.useFixture(database.Database())
+        super().setUp()
+        self.database_fixture = self.useFixture(database.Database())
         self.load_backends()
 
         # populate the engine with tables & fixtures
@@ -76,7 +76,7 @@ class DataTypeRoundTrips(SqlTests):
         with sql.session_for_read() as session:
             val = session.scalar(
                 sqlalchemy.select(
-                    [sqlalchemy.literal({"key": "value"}, type_=core.JsonBlob)]
+                    sqlalchemy.literal({"key": "value"}, type_=core.JsonBlob),
                 )
             )
 
@@ -95,7 +95,7 @@ class DataTypeRoundTrips(SqlTests):
         with sql.session_for_read() as session:
             val = session.scalar(
                 sqlalchemy.select(
-                    [sqlalchemy.cast(sqlalchemy.null(), type_=core.JsonBlob)]
+                    sqlalchemy.cast(sqlalchemy.null(), type_=core.JsonBlob),
                 )
             )
 
@@ -112,7 +112,7 @@ class DataTypeRoundTrips(SqlTests):
         with sql.session_for_read() as session:
             val = session.scalar(
                 sqlalchemy.select(
-                    [sqlalchemy.literal(None, type_=core.JsonBlob)]
+                    sqlalchemy.literal(None, type_=core.JsonBlob),
                 )
             )
 
@@ -123,12 +123,10 @@ class DataTypeRoundTrips(SqlTests):
         with sql.session_for_read() as session:
             val = session.scalar(
                 sqlalchemy.select(
-                    [
-                        sqlalchemy.cast(
-                            sqlalchemy.literal(None, type_=core.JsonBlob),
-                            sqlalchemy.String,
-                        )
-                    ]
+                    sqlalchemy.cast(
+                        sqlalchemy.literal(None, type_=core.JsonBlob),
+                        sqlalchemy.String,
+                    ),
                 )
             )
 
@@ -140,11 +138,9 @@ class DataTypeRoundTrips(SqlTests):
             datetime_value = datetime.datetime(2019, 5, 15, 10, 17, 55)
             val = session.scalar(
                 sqlalchemy.select(
-                    [
-                        sqlalchemy.literal(
-                            datetime_value, type_=core.DateTimeInt
-                        ),
-                    ]
+                    sqlalchemy.literal(
+                        datetime_value, type_=core.DateTimeInt
+                    ),
                 )
             )
 
@@ -156,14 +152,12 @@ class DataTypeRoundTrips(SqlTests):
             datetime_value = datetime.datetime(2019, 5, 15, 10, 17, 55)
             val = session.scalar(
                 sqlalchemy.select(
-                    [
-                        sqlalchemy.cast(
-                            sqlalchemy.literal(
-                                datetime_value, type_=core.DateTimeInt
-                            ),
-                            sqlalchemy.Integer
-                        )
-                    ]
+                    sqlalchemy.cast(
+                        sqlalchemy.literal(
+                            datetime_value, type_=core.DateTimeInt
+                        ),
+                        sqlalchemy.Integer
+                    ),
                 )
             )
 
@@ -174,9 +168,7 @@ class DataTypeRoundTrips(SqlTests):
         with sql.session_for_read() as session:
             val = session.scalar(
                 sqlalchemy.select(
-                    [
-                        sqlalchemy.literal(None, type_=core.DateTimeInt),
-                    ]
+                    sqlalchemy.literal(None, type_=core.DateTimeInt),
                 )
             )
 
@@ -186,9 +178,11 @@ class DataTypeRoundTrips(SqlTests):
 class SqlModels(SqlTests):
 
     def load_table(self, name):
-        table = sqlalchemy.Table(name,
-                                 sql.ModelBase.metadata,
-                                 autoload=True)
+        table = sqlalchemy.Table(
+            name,
+            sql.ModelBase.metadata,
+            autoload_with=self.database_fixture.engine,
+        )
         return table
 
     def assertExpectedSchema(self, table, expected_schema):
@@ -244,7 +238,7 @@ class SqlModels(SqlTests):
             else:
                 actual_schema.append((column.name, type(column.type), None))
 
-        self.assertItemsEqual(expected_schema, actual_schema)
+        self.assertCountEqual(expected_schema, actual_schema)
 
     def test_user_model(self):
         cols = (('id', sql.String, 64),
@@ -1028,7 +1022,7 @@ class SqlTrust(SqlTests, trust_tests.TrustTests):
         with sql.session_for_write() as session:
             new_id = uuid.uuid4().hex
             self.create_sample_trust(new_id)
-            trust_ref = session.query(trust_sql.TrustModel).get(new_id)
+            trust_ref = session.get(trust_sql.TrustModel, new_id)
             self.assertIsNotNone(trust_ref._expires_at)
             self.assertEqual(trust_ref._expires_at, trust_ref.expires_at_int)
             self.assertEqual(trust_ref.expires_at, trust_ref.expires_at_int)
@@ -1194,7 +1188,7 @@ class SqlCatalog(SqlTests, catalog_tests.CatalogTests):
         )
         self.assertThat(catalog_ref, matchers.HasLength(2))
         srv_id_list = [catalog_ref[0]['id'], catalog_ref[1]['id']]
-        self.assertItemsEqual([srv_1['id'], srv_2['id']], srv_id_list)
+        self.assertCountEqual([srv_1['id'], srv_2['id']], srv_id_list)
 
 
 class SqlPolicy(SqlTests, policy_tests.PolicyTests):
