@@ -132,16 +132,28 @@ class CliBootStrapTestCase(unit.SQLDriverOverrides, unit.TestCase):
             bootstrap.username,
             'default')
         admin_role = PROVIDERS.role_api.get_role(bootstrap.role_id)
-        reader_role = PROVIDERS.role_api.get_role(bootstrap.reader_role_id)
+        manager_role = PROVIDERS.role_api.get_role(bootstrap.manager_role_id)
         member_role = PROVIDERS.role_api.get_role(bootstrap.member_role_id)
+        reader_role = PROVIDERS.role_api.get_role(bootstrap.reader_role_id)
+        service_role = PROVIDERS.role_api.get_role(bootstrap.service_role_id)
         role_list = (
             PROVIDERS.assignment_api.get_roles_for_user_and_project(
                 user['id'],
                 project['id']))
-        self.assertIs(3, len(role_list))
+
+        role_list_len = 5
+        if bootstrap.bootstrapper.project_name:
+            role_list_len = 4
+
+        self.assertIs(role_list_len, len(role_list))
         self.assertIn(admin_role['id'], role_list)
-        self.assertIn(reader_role['id'], role_list)
+        self.assertIn(manager_role['id'], role_list)
         self.assertIn(member_role['id'], role_list)
+        self.assertIn(reader_role['id'], role_list)
+
+        if not bootstrap.bootstrapper.project_name:
+            self.assertIn(service_role['id'], role_list)
+
         system_roles = (
             PROVIDERS.assignment_api.list_system_grants_for_user(
                 user['id']
@@ -352,7 +364,7 @@ class CliBootStrapTestCase(unit.SQLDriverOverrides, unit.TestCase):
         domain = PROVIDERS.resource_api.create_domain(domain['id'], domain)
         domain_roles = {}
 
-        for name in ['admin', 'member', 'reader']:
+        for name in ['admin', 'member', 'reader', 'service']:
             domain_role = {
                 'domain_id': domain['id'],
                 'id': uuid.uuid4().hex,
@@ -754,18 +766,28 @@ class CliDBSyncTestCase(unit.BaseTestCase):
             self.version = None
 
     def setUp(self):
-        super(CliDBSyncTestCase, self).setUp()
+        super().setUp()
         self.config_fixture = self.useFixture(oslo_config.fixture.Config(CONF))
         self.config_fixture.register_cli_opt(cli.command_opt)
-        upgrades.offline_sync_database_to_version = mock.Mock()
-        upgrades.expand_schema = mock.Mock()
-        upgrades.migrate_data = mock.Mock()
-        upgrades.contract_schema = mock.Mock()
+
+        self.patchers = patchers = [
+            mock.patch.object(upgrades, "offline_sync_database_to_version"),
+            mock.patch.object(upgrades, "expand_schema"),
+            mock.patch.object(upgrades, "migrate_data"),
+            mock.patch.object(upgrades, "contract_schema"),
+        ]
+        for p in patchers:
+            p.start()
         self.command_check = False
         self.command_expand = False
         self.command_migrate = False
         self.command_contract = False
 
+    def tearDown(self):
+        for p in self.patchers:
+            p.stop()
+        super().tearDown()
+
     def _assert_correct_call(self, mocked_function):
         for func in [upgrades.offline_sync_database_to_version,
                      upgrades.expand_schema,
